pub struct DagBuilderThen<CONTEXT: Send + Sync, ERROR: Error + Send + Sync, RESOURCE: Clone + Debug + DeserializeOwned + Resource<DynamicType = ()> + Send + Sync, TASK: Task<CONTEXT, ERROR, RESOURCE>>(/* private fields */);Expand description
A DAG builder with the first group of tasks already configured.
Implementations
Sourceimpl<CONTEXT: Send + Sync, ERROR: Error + Send + Sync, RESOURCE: Clone + Debug + DeserializeOwned + Resource<DynamicType = ()> + Send + Sync, TASK: Task<CONTEXT, ERROR, RESOURCE>> DagBuilderThen<CONTEXT, ERROR, RESOURCE, TASK>
impl<CONTEXT: Send + Sync, ERROR: Error + Send + Sync, RESOURCE: Clone + Debug + DeserializeOwned + Resource<DynamicType = ()> + Send + Sync, TASK: Task<CONTEXT, ERROR, RESOURCE>> DagBuilderThen<CONTEXT, ERROR, RESOURCE, TASK>
Sourcepub fn action(self, action: Action) -> Self
pub fn action(self, action: Action) -> Self
Define the final action of the DAG (when all tasks are completed).
Sourcepub fn requeue_delay(self, delay: Duration) -> Self
pub fn requeue_delay(self, delay: Duration) -> Self
Define the delay between two reconciliations.
Sourcepub fn then<TASKS: IntoIterator<Item = TASK>>(self, tasks: TASKS) -> Self
pub fn then<TASKS: IntoIterator<Item = TASK>>(self, tasks: TASKS) -> Self
Define the next group of tasks to run. It will be started when all tasks of the current group are completed.